Skip to contents

Connects to a MongoDB database and retrieves all documents from a specified collection, maintaining the original column order if a metadata document is present.

Usage

mdb_collection_pull(
  connection_string = NULL,
  collection_name = NULL,
  db_name = NULL
)

Arguments

connection_string

A character string specifying the MongoDB connection URL.

collection_name

A character string specifying the name of the collection.

db_name

A character string specifying the name of the database.

Value

A data frame containing all documents from the specified collection.