Fetches taxa, gear, vessels, and landing sites data from Airtable.
Returns distinct records for each table.
Usage
fetch_assets(conf = NULL)
Arguments
- conf
Configuration object from read_config().
Value
A named list containing four data frames:
taxa: Contains survey_label, alpha3_code, and scientific_name columns
gear: Contains survey_label and standard_name columns
vessels: Contains survey_label and standard_name columns
sites: Contains site and site_code columns
Details
Each table is fetched separately using `fetch_asset()` and filtered to return
only distinct rows to avoid duplicates in the mapping tables.